@@ -16,6 +16,7 @@ import statistics
 import subprocess
 import sys
 import time
+import traceback
 
 from pathlib import Path
 
@@ -58,7 +59,7 @@ class ShellSession:
             self.foutput.close()
 
     @contextlib.contextmanager
-    def set_env(self, *env_varss: dict[str, str] | None) -> Iterator[None]:
+    def set_env(self, *env_varss: Env_VarsType) -> Iterator[None]:
         """Set environment variables.
 
         All the arguments are dicts of name:value, or None.  All are applied
@@ -115,12 +116,13 @@ class ShellSession:
         return output.strip()
 
 
-def rmrf(path: Path) -> None:
+def remake(path: Path) -> None:
     """
-    Remove a directory tree.  It's OK if it doesn't exist.
+    Remove a directory tree and recreate it.  It's OK if it doesn't exist.
     """
     if path.exists():
         shutil.rmtree(path)
+    path.mkdir(parents=True)
 
 
 @contextlib.contextmanager
@@ -203,8 +205,9 @@ class ProjectToTest:
 
     def make_dir(self) -> None:
         self.dir = Path(f"work_{self.slug}")
-        if self.dir.exists():
-            rmrf(self.dir)
+        remake(self.dir)
+        self.tmpdir = Path(f"tmp_{self.slug}").resolve()
+        remake(self.tmpdir)
 
     def get_source(self, shell: ShellSession, retries: int = 5) -> None:
         """Get the source of the project."""
@@ -276,10 +279,18 @@ class EmptyProject(ProjectToTest):
 class ToxProject(ProjectToTest):
     """A project using tox to run the test suite."""
 
+    ALLOWABLE_ENV_VARS = [
+        "COVERAGE_DEBUG",
+        "COVERAGE_CORE",
+        "COVERAGE_FORCE_CONFIG",
+        "PATH",
+        "TMPDIR",
+    ]
+
     env_vars: Env_VarsType = {
         **(ProjectToTest.env_vars or {}),
         # Allow some environment variables into the tox execution.
-        "TOX_OVERRIDE": "testenv.pass_env+=COVERAGE_DEBUG,COVERAGE_CORE",
+        "TOX_OVERRIDE": "testenv.pass_env+=" + ",".join(ALLOWABLE_ENV_VARS),
     }
 
     def prep_environment(self, env: Env) -> None:
@@ -421,22 +432,19 @@ class ProjectOperator(ProjectToTest):
 
     def prep_environment(self, env: Env) -> None:
         env.shell.run_command(f"{env.python} -m pip install tox")
-        Path("/tmp/operator_tmp").mkdir(exist_ok=True)
         env.shell.run_command(f"{env.python} -m tox -e unit --notest")
         env.shell.run_command(f"{env.python} -m tox -e unitnocov --notest")
 
     def run_no_coverage(self, env: Env) -> float:
         env.shell.run_command(
-            f"TMPDIR=/tmp/operator_tmp {env.python} -m tox -e unitnocov --skip-pkg-install"
-            + f" -- {self.more_pytest_args}"
+            f"{env.python} -m tox -e unitnocov --skip-pkg-install -- {self.more_pytest_args}"
         )
         return env.shell.last_duration
 
     def run_with_coverage(self, env: Env, cov_ver: Coverage) -> float:
         env.shell.run_command(f"{env.python} -m pip install {cov_ver.pip_args}")
         env.shell.run_command(
-            f"TMPDIR=/tmp/operator_tmp {env.python} -m tox -e unit --skip-pkg-install"
-            + f" -- {self.more_pytest_args}"
+            f"{env.python} -m tox -e unit --skip-pkg-install -- {self.more_pytest_args}"
         )
         duration = env.shell.last_duration
         report = env.shell.run_command(f"{env.python} -m coverage report --precision=6")
@@ -553,47 +561,37 @@ class ProjectMpmath(ProjectToTest):
 class ProjectMypy(ToxProject):
     git_url = "https://github.com/python/mypy"
 
-    # Slow test suites
-    CMDLINE = "PythonCmdline"
-    PEP561 = "PEP561Suite"
-    EVALUATION = "PythonEvaluation"
-    DAEMON = "testdaemon"
-    STUBGEN_CMD = "StubgenCmdLine"
-    STUBGEN_PY = "StubgenPythonSuite"
-    MYPYC_RUN = "TestRun"
-    MYPYC_RUN_MULTI = "TestRunMultiFile"
-    MYPYC_EXTERNAL = "TestExternal"
-    MYPYC_COMMAND_LINE = "TestCommandLine"
-    ERROR_STREAM = "ErrorStreamSuite"
+    SLOW_TESTS = " or ".join([
+        "PythonCmdline",
+        "PEP561Suite",
+        "PythonEvaluation",
+        "testdaemon",
+        "StubgenCmdLine",
+        "StubgenPythonSuite",
+        "TestRun",
+        "TestRunMultiFile",
+        "TestExternal",
+        "TestCommandLine",
+        "ErrorStreamSuite",
+    ])
 
-    ALL_NON_FAST = (
-        CMDLINE,
-        PEP561,
-        EVALUATION,
-        DAEMON,
-        STUBGEN_CMD,
-        STUBGEN_PY,
-        MYPYC_RUN,
-        MYPYC_RUN_MULTI,
-        MYPYC_EXTERNAL,
-        MYPYC_COMMAND_LINE,
-        ERROR_STREAM,
-    )
-
-    FAST = "pytest", "-k", f"\"not ({' or '.join(ALL_NON_FAST)})\""
+    FAST = f"-k 'not ({SLOW_TESTS})'"
 
     def prep_environment(self, env: Env) -> None:
         env.shell.run_command(f"{env.python} -m pip install -r test-requirements.txt")
 
     def run_no_coverage(self, env: Env) -> float:
-        env.shell.run_command(f"{env.python} -m {' '.join(self.FAST)} --no-cov")
+        env.shell.run_command(f"{env.python} -m pytest {self.FAST} --no-cov")
         return env.shell.last_duration
 
     def run_with_coverage(self, env: Env, cov_ver: Coverage) -> float:
         env.shell.run_command(f"{env.python} -m pip install {cov_ver.pip_args}")
-        env.shell.run_command(f"{env.python} -m {' '.join(self.FAST)} --cov")
-        duration = env.shell.last_duration
-        report = env.shell.run_command(f"{env.python} -m coverage report --precision=6")
+        pforce = Path("force.ini")
+        pforce.write_text("[run]\nbranch=false\n")
+        with env.shell.set_env({"COVERAGE_FORCE_CONFIG": str(pforce.resolve())}):
+            env.shell.run_command(f"{env.python} -m pytest {self.FAST} --cov")
+            duration = env.shell.last_duration
+            report = env.shell.run_command(f"{env.python} -m coverage report --precision=6")
         print("Results:", report.splitlines()[-1])
         return duration
 
@@ -820,7 +818,7 @@ class CoverageSource(Coverage):
 
     def __init__(
         self,
-        directory_name: str,
+        directory_name: str = "..",
         slug: str = "source",
         tweaks: TweaksType = None,
         env_vars: Env_VarsType = None,
@@ -856,18 +854,17 @@ class Experiment:
         py_versions: list[PyVersion],
         cov_versions: list[Coverage],
         projects: list[ProjectToTest],
-        results_file: str = "results.json",
+        results_file: Path = Path("results.json"),
         load: bool = False,
-        cwd: str = "",
     ):
         self.py_versions = py_versions
         self.cov_versions = cov_versions
         self.projects = projects
-        self.results_file = Path(cwd) / Path(results_file)
-        self.result_data: dict[ResultKey, list[float]] = (
-            self.load_results() if load else {}
-        )
+        self.results_file = results_file
+        self.result_data: dict[ResultKey, list[float]] = {}
         self.summary_data: dict[ResultKey, float] = {}
+        if load:
+            self.result_data = self.load_results()
 
     def save_results(self) -> None:
         """Save current results to the JSON file."""
@@ -941,8 +938,13 @@ class Experiment:
                 )
                 print(banner)
                 env.shell.print_banner(banner)
+                env_vars = [
+                    proj.env_vars,
+                    cov_ver.env_vars,
+                    {"TMPDIR": str(proj.tmpdir)},
+                ]
                 with change_dir(proj.dir):
-                    with env.shell.set_env(proj.env_vars, cov_ver.env_vars):
+                    with env.shell.set_env(*env_vars):
                         try:
                             if cov_ver.pip_args is None:
                                 dur = proj.run_no_coverage(env)
@@ -950,6 +952,7 @@ class Experiment:
                                 dur = proj.run_with_coverage(env, cov_ver)
                         except Exception as exc:
                             print(f"!!! {exc = }")
+                            traceback.print_exc(file=env.shell.foutput)
                             dur = float("NaN")
             print(f"Tests took {dur:.3f}s")
             if result_key not in self.result_data:
@@ -957,6 +960,7 @@ class Experiment:
             self.result_data[result_key].append(dur)
             run_data[result_key].append(dur)
             self.save_results()
+
         # Summarize and collect the data.
         print("# Results")
         for proj in self.projects:
@@ -1062,16 +1066,16 @@ def run_experiment(
         )
 
     print(f"Removing and re-making {PERF_DIR}")
-    rmrf(PERF_DIR)
+    remake(PERF_DIR)
 
-    cwd = str(Path.cwd())
+    results_file = Path("results.json").resolve()
     with change_dir(PERF_DIR):
         exp = Experiment(
             py_versions=py_versions,
             cov_versions=cov_versions,
             projects=projects,
+            results_file=results_file,
             load=load,
-            cwd=cwd,
         )
         exp.run(num_runs=int(num_runs))
         exp.show_results(rows=rows, column=column, ratios=ratios)
