@@ -5,9 +5,9 @@
 
 from __future__ import annotations
 
+import collections
 import contextlib
 import datetime
-import difflib
 import glob
 import io
 import os
@@ -19,9 +19,9 @@ import sys
 
 from types import ModuleType
 from typing import (
-    Any, Collection, Dict, Iterable, Iterator, List, Mapping, Optional,
-    Sequence, Tuple, Union,
+    Any,
 )
+from collections.abc import Collection, Iterable, Iterator, Mapping, Sequence
 
 import coverage
 from coverage import Coverage
@@ -30,7 +30,7 @@ from coverage.data import CoverageData
 from coverage.misc import import_local_file
 from coverage.types import TArc, TLineNo
 
-from tests.helpers import arcs_to_arcz_repr, arcz_to_arcs, assert_count_equal
+from tests.helpers import arcz_to_arcs, assert_count_equal
 from tests.helpers import nice_file, run_command
 from tests.mixins import PytestBase, StdStreamCapturingMixin, RestoreModulesMixin, TempDirMixin
 
@@ -47,6 +47,23 @@ TESTS_DIR = os.path.dirname(__file__)
 COVERAGE_INSTALL_ARGS = os.getenv("COVERAGE_INSTALL_ARGS", nice_file(TESTS_DIR, ".."))
 
 
+def arcs_to_branches(arcs: Iterable[TArc]) -> dict[TLineNo, list[TLineNo]]:
+    """Convert a list of arcs into a dict showing branches."""
+    arcs_combined = collections.defaultdict(set)
+    for fromno, tono in arcs:
+        arcs_combined[fromno].add(tono)
+    branches = collections.defaultdict(list)
+    for fromno, tono in arcs:
+        if len(arcs_combined[fromno]) > 1:
+            branches[fromno].append(tono)
+    return branches
+
+
+def branches_to_arcs(branches: dict[TLineNo, list[TLineNo]]) -> list[TArc]:
+    """Convert a dict od branches into a list of arcs."""
+    return [(fromno, tono) for fromno, tonos in branches.items() for tono in tonos]
+
+
 class CoverageTest(
     StdStreamCapturingMixin,
     RestoreModulesMixin,
@@ -68,15 +85,15 @@ class CoverageTest(
         super().setUp()
 
         # Attributes for getting info about what happened.
-        self.last_command_status: Optional[int] = None
-        self.last_command_output: Optional[str] = None
-        self.last_module_name: Optional[str] = None
+        self.last_command_status: int | None = None
+        self.last_command_output: str | None = None
+        self.last_module_name: str | None = None
 
     def start_import_stop(
         self,
         cov: Coverage,
         modname: str,
-        modfile: Optional[str] = None
+        modfile: str | None = None,
     ) -> ModuleType:
         """Start coverage, import a file, then stop coverage.
 
@@ -126,42 +143,16 @@ class CoverageTest(
         self.last_module_name = 'coverage_test_' + str(random.random())[2:]
         return self.last_module_name
 
-    def _check_arcs(
-        self,
-        a1: Optional[Iterable[TArc]],
-        a2: Optional[Iterable[TArc]],
-        arc_type: str,
-    ) -> str:
-        """Check that the arc lists `a1` and `a2` are equal.
-
-        If they are equal, return empty string. If they are unequal, return
-        a string explaining what is different.
-        """
-        # Make them into multi-line strings so we can see what's going wrong.
-        s1 = arcs_to_arcz_repr(a1)
-        s2 = arcs_to_arcz_repr(a2)
-        if s1 != s2:
-            lines1 = s1.splitlines(True)
-            lines2 = s2.splitlines(True)
-            diff = "".join(difflib.ndiff(lines1, lines2))
-            return "\n" + arc_type + " arcs differ: minus is expected, plus is actual\n" + diff
-        else:
-            return ""
-
     def check_coverage(
         self,
         text: str,
-        lines: Optional[Union[Sequence[TLineNo], Sequence[List[TLineNo]]]] = None,
-        missing: Union[str, Sequence[str]] = "",
+        lines: Sequence[TLineNo] | Sequence[list[TLineNo]] | None = None,
+        missing: str = "",
         report: str = "",
-        excludes: Optional[Iterable[str]] = None,
+        excludes: Iterable[str] | None = None,
         partials: Iterable[str] = (),
-        arcz: Optional[str] = None,
-        arcz_missing: Optional[str] = None,
-        arcz_unpredicted: Optional[str] = None,
-        arcs: Optional[Iterable[TArc]] = None,
-        arcs_missing: Optional[Iterable[TArc]] = None,
-        arcs_unpredicted: Optional[Iterable[TArc]] = None,
+        branchz: str | None = None,
+        branchz_missing: str | None = None,
     ) -> Coverage:
         """Check the coverage measurement of `text`.
 
@@ -171,12 +162,9 @@ class CoverageTest(
         regexes to match against for excluding lines, and `report` is the text
         of the measurement report.
 
-        For arc measurement, `arcz` is a string that can be decoded into arcs
-        in the code (see `arcz_to_arcs` for the encoding scheme).
-        `arcz_missing` are the arcs that are not executed, and
-        `arcz_unpredicted` are the arcs executed in the code, but not deducible
-        from the code.  These last two default to "", meaning we explicitly
-        check that there are no missing or unpredicted arcs.
+        For branch measurement, `branchz` is a string that can be decoded into
+        arcs in the code (see `arcz_to_arcs` for the encoding scheme).
+        `branchz_missing` are the arcs that are not executed.
 
         Returns the Coverage object, in case you want to poke at it some more.
 
@@ -189,12 +177,11 @@ class CoverageTest(
 
         self.make_file(modname + ".py", text)
 
-        if arcs is None and arcz is not None:
-            arcs = arcz_to_arcs(arcz)
-        if arcs_missing is None and arcz_missing is not None:
-            arcs_missing = arcz_to_arcs(arcz_missing)
-        if arcs_unpredicted is None and arcz_unpredicted is not None:
-            arcs_unpredicted = arcz_to_arcs(arcz_unpredicted)
+        branches = branches_missing = None
+        if branchz is not None:
+            branches = arcz_to_arcs(branchz)
+        if branchz_missing is not None:
+            branches_missing = arcz_to_arcs(branchz_missing)
 
         # Start up coverage.py.
         cov = coverage.Coverage(branch=True)
@@ -227,30 +214,22 @@ class CoverageTest(
                     assert False, f"None of the lines choices matched {statements!r}"
 
             missing_formatted = analysis.missing_formatted()
-            if isinstance(missing, str):
-                msg = f"missing: {missing_formatted!r} != {missing!r}"
-                assert missing_formatted == missing, msg
-            else:
-                for missing_list in missing:
-                    if missing_formatted == missing_list:
-                        break
-                else:
-                    assert False, f"None of the missing choices matched {missing_formatted!r}"
+            msg = f"missing: {missing_formatted!r} != {missing!r}"
+            assert missing_formatted == missing, msg
 
-        if arcs is not None:
-            # print("Possible arcs:")
-            # print(" expected:", arcs)
-            # print(" actual:", analysis.arc_possibilities())
-            # print("Executed:")
-            # print(" actual:", sorted(set(analysis.arcs_executed())))
-            # TODO: this would be nicer with pytest-check, once we can run that.
-            msg = (
-                self._check_arcs(arcs, analysis.arc_possibilities(), "Possible") +
-                self._check_arcs(arcs_missing, analysis.arcs_missing(), "Missing") +
-                self._check_arcs(arcs_unpredicted, analysis.arcs_unpredicted(), "Unpredicted")
+        if branches is not None:
+            trimmed_arcs = branches_to_arcs(arcs_to_branches(analysis.arc_possibilities))
+            assert branches == trimmed_arcs, (
+                f"Wrong possible branches: {branches} != {trimmed_arcs}"
             )
-            if msg:
-                assert False, msg
+            if branches_missing is not None:
+                assert set(branches_missing) <= set(branches), (
+                    f"{branches_missing = }, has non-branches in it."
+                )
+                analysis_missing = branches_to_arcs(analysis.missing_branch_arcs())
+                assert branches_missing == analysis_missing, (
+                    f"Wrong missing branches: {branches_missing} != {analysis_missing}"
+                )
 
         if report:
             frep = io.StringIO()
@@ -262,11 +241,12 @@ class CoverageTest(
 
     def make_data_file(
         self,
-        basename: Optional[str] = None,
-        suffix: Optional[str] = None,
-        lines: Optional[Mapping[str, Collection[TLineNo]]] = None,
-        arcs: Optional[Mapping[str, Collection[TArc]]] = None,
-        file_tracers: Optional[Mapping[str, str]] = None,
+        basename: str | None = None,
+        *,
+        suffix: str | None = None,
+        lines: Mapping[str, Collection[TLineNo]] | None = None,
+        arcs: Mapping[str, Collection[TArc]] | None = None,
+        file_tracers: Mapping[str, str] | None = None,
     ) -> CoverageData:
         """Write some data into a coverage data file."""
         data = coverage.CoverageData(basename=basename, suffix=suffix)
@@ -306,7 +286,7 @@ class CoverageTest(
         saved_warnings = []
         def capture_warning(
             msg: str,
-            slug: Optional[str] = None,
+            slug: str | None = None,
             once: bool = False,                 # pylint: disable=unused-argument
         ) -> None:
             """A fake implementation of Coverage._warn, to capture warnings."""
@@ -368,7 +348,7 @@ class CoverageTest(
         self,
         dt: datetime.datetime,
         seconds: int = 10,
-        msg: Optional[str] = None,
+        msg: str | None = None,
     ) -> None:
         """Assert that `dt` marks a time at most `seconds` seconds ago."""
         age = datetime.datetime.now() - dt
@@ -397,11 +377,11 @@ class CoverageTest(
     coverage_command = "coverage"
 
     def run_command(self, cmd: str) -> str:
-        """Run the command-line `cmd` in a sub-process.
+        """Run the command-line `cmd` in a subprocess.
 
-        `cmd` is the command line to invoke in a sub-process. Returns the
+        `cmd` is the command line to invoke in a subprocess. Returns the
         combined content of `stdout` and `stderr` output streams from the
-        sub-process.
+        subprocess.
 
         See `run_command_status` for complete semantics.
 
@@ -413,8 +393,8 @@ class CoverageTest(
         _, output = self.run_command_status(cmd)
         return output
 
-    def run_command_status(self, cmd: str) -> Tuple[int, str]:
-        """Run the command-line `cmd` in a sub-process, and print its output.
+    def run_command_status(self, cmd: str) -> tuple[int, str]:
+        """Run the command-line `cmd` in a subprocess, and print its output.
 
         Use this when you need to test the process behavior of coverage.
 
@@ -440,7 +420,7 @@ class CoverageTest(
         command_args = split_commandline[1:]
 
         if command_name == "python":
-            # Running a Python interpreter in a sub-processes can be tricky.
+            # Running a Python interpreter in a subprocesses can be tricky.
             # Use the real name of our own executable. So "python foo.py" might
             # get executed as "python3.3 foo.py". This is important because
             # Python 3.x doesn't install as "python", so you might get a Python
@@ -479,7 +459,7 @@ class CoverageTest(
         assert "error" not in report.lower()
         return report
 
-    def report_lines(self, report: str) -> List[str]:
+    def report_lines(self, report: str) -> list[str]:
         """Return the lines of the report, as a list."""
         lines = report.split('\n')
         assert lines[-1] == ""
@@ -489,7 +469,7 @@ class CoverageTest(
         """How many lines are in `report`?"""
         return len(self.report_lines(report))
 
-    def squeezed_lines(self, report: str) -> List[str]:
+    def squeezed_lines(self, report: str) -> list[str]:
         """Return a list of the lines in report, with the spaces squeezed."""
         lines = self.report_lines(report)
         return [re.sub(r"\s+", " ", l.strip()) for l in lines]
@@ -498,7 +478,7 @@ class CoverageTest(
         """Return the last line of `report` with the spaces squeezed down."""
         return self.squeezed_lines(report)[-1]
 
-    def get_measured_filenames(self, coverage_data: CoverageData) -> Dict[str, str]:
+    def get_measured_filenames(self, coverage_data: CoverageData) -> dict[str, str]:
         """Get paths to measured files.
 
         Returns a dict of {filename: absolute path to file}
@@ -513,7 +493,7 @@ class CoverageTest(
         assert self.last_module_name is not None
         filename = self.last_module_name + ".py"
         fr = cov._get_file_reporter(filename)
-        arcs_executed = cov._analyze(filename).arcs_executed()
+        arcs_executed = cov._analyze(filename).arcs_executed
         return fr.missing_arc_description(start, end, arcs_executed)
 
 
