@@ -11,7 +11,8 @@ import os
 import re
 import sys
 
-from typing import Any, Callable, Iterable
+from typing import Any, Callable
+from collections.abc import Iterable
 
 import pytest
 
@@ -25,6 +26,7 @@ from coverage.debug import (
 )
 from coverage.exceptions import DataError
 
+from tests import testenv
 from tests.coveragetest import CoverageTest
 from tests.helpers import DebugControlString, re_line, re_lines, re_lines_text
 
@@ -178,7 +180,7 @@ class DebugTraceTest(CoverageTest):
         out_text = self.f1_debug_output(["config"])
 
         labels = """
-            attempted_config_files branch config_files_read config_file cover_pylib data_file
+            branch config_file config_files_attempted config_files_read cover_pylib data_file
             debug exclude_list extra_css html_dir html_title ignore_errors
             run_include run_omit parallel partial_always_list partial_list paths
             precision show_missing source timid xml_output
@@ -196,7 +198,7 @@ class DebugTraceTest(CoverageTest):
     def test_debug_sys_ctracer(self) -> None:
         out_text = self.f1_debug_output(["sys"])
         tracer_line = re_line(r"CTracer:", out_text).strip()
-        if env.C_TRACER:
+        if testenv.C_TRACER or testenv.SYS_MON:
             expected = "CTracer: available"
         else:
             expected = "CTracer: unavailable"
@@ -224,7 +226,7 @@ def assert_good_debug_sys(out_text: str) -> None:
     """Assert that `str` is good output for debug=sys."""
     labels = """
         coverage_version coverage_module coverage_paths stdlib_paths third_party_paths
-        tracer configs_attempted config_file configs_read data_file
+        core configs_attempted config_file configs_read data_file
         python platform implementation executable
         pid cwd path environment command_line cover_match pylib_match
         """.split()
@@ -232,6 +234,14 @@ def assert_good_debug_sys(out_text: str) -> None:
         label_pat = fr"^\s*{label}: "
         msg = f"Incorrect lines for {label!r}"
         assert 1 == len(re_lines(label_pat, out_text)), msg
+    tracer_line = re_line(" core:", out_text).strip()
+    if testenv.C_TRACER:
+        assert tracer_line == "core: CTracer"
+    elif testenv.PY_TRACER:
+        assert tracer_line == "core: PyTracer"
+    else:
+        assert testenv.SYS_MON
+        assert tracer_line == "core: SysMonitor"
 
 
 class DebugOutputTest(CoverageTest):
@@ -367,7 +377,7 @@ class ShortStackTest(CoverageTest):
         else:
             py = "pypy" if env.PYPY else "python"
             majv, minv = sys.version_info[:2]
-            pylib = f"lib{s}{py}{majv}.{minv}"
+            pylib = f"lib{s}{py}{majv}.{minv}{sys.abiflags}"
         assert len(re_lines(fr"{s}{pylib}{s}site-packages{s}_pytest", stack_text)) > 3
         assert len(re_lines(fr"{s}{pylib}{s}site-packages{s}pluggy", stack_text)) > 3
         assert not re_lines(r" 0x[0-9a-fA-F]+", stack_text) # No frame ids
