@@ -10,7 +10,8 @@ import os
 import os.path
 import re
 
-from typing import Any, Iterable, Iterator, List, Protocol
+from typing import Any, Protocol
+from collections.abc import Iterable, Iterator
 from unittest import mock
 
 import pytest
@@ -78,7 +79,7 @@ class FilesTest(CoverageTest):
         "curdir, sep", [
             ("/", "/"),
             ("X:\\", "\\"),
-        ]
+        ],
     )
     def test_relative_dir_for_root(self, curdir: str, sep: str) -> None:
         with mock.patch.object(files.os, 'curdir', new=curdir):
@@ -97,7 +98,7 @@ class FilesTest(CoverageTest):
             ("src/files.pex", "src/files.pex/foo.py", True),
             ("src/files.zip", "src/morefiles.zip/foo.py", False),
             ("src/files.pex", "src/files.pex/zipfiles/files.zip/foo.py", True),
-        ]
+        ],
     )
     def test_source_exists(self, to_make: str, to_check: str, answer: bool) -> None:
         # source_exists won't look inside the zipfile, so it's fine to make
@@ -109,13 +110,13 @@ class FilesTest(CoverageTest):
 @pytest.mark.parametrize("original, flat", [
     ("abc.py", "abc_py"),
     ("hellothere", "hellothere"),
-    ("a/b/c.py", "d_86bbcbe134d28fd2_c_py"),
-    ("a/b/defghi.py", "d_86bbcbe134d28fd2_defghi_py"),
-    ("/a/b/c.py", "d_bb25e0ada04227c6_c_py"),
-    ("/a/b/defghi.py", "d_bb25e0ada04227c6_defghi_py"),
-    (r"c:\foo\bar.html", "d_e7c107482373f299_bar_html"),
-    (r"d:\foo\bar.html", "d_584a05dcebc67b46_bar_html"),
-    ("Montréal/☺/conf.py", "d_c840497a2c647ce0_conf_py"),
+    ("a/b/c.py", "z_86bbcbe134d28fd2_c_py"),
+    ("a/b/defghi.py", "z_86bbcbe134d28fd2_defghi_py"),
+    ("/a/b/c.py", "z_bb25e0ada04227c6_c_py"),
+    ("/a/b/defghi.py", "z_bb25e0ada04227c6_defghi_py"),
+    (r"c:\foo\bar.html", "z_e7c107482373f299_bar_html"),
+    (r"d:\foo\bar.html", "z_584a05dcebc67b46_bar_html"),
+    ("Montréal/☺/conf.py", "z_c840497a2c647ce0_conf_py"),
     ( # original:
         r"c:\lorem\ipsum\quia\dolor\sit\amet\consectetur\adipisci\velit\sed" +
         r"\quia\non\numquam\eius\modi\tempora\incidunt\ut\labore\et\dolore" +
@@ -123,7 +124,7 @@ class FilesTest(CoverageTest):
         r"\nostrum\exercitationem\ullam\corporis\suscipit\laboriosam" +
         r"\Montréal\☺\my_program.py",
         # flat:
-        "d_e597dfacb73a23d5_my_program_py"
+        "z_e597dfacb73a23d5_my_program_py",
      ),
 ])
 def test_flat_rootname(original: str, flat: str) -> None:
@@ -235,9 +236,24 @@ def globs_to_regex_params(
         ),
         globs_to_regex_params(
             ["*/foo"], case_insensitive=False, partial=True,
-            matches=["abc/foo/hi.py", "foo/hi.py"],
+            matches=["abc/foo/hi.py", "foo/hi.py", "abc/def/foo/hi.py"],
             nomatches=["abc/xfoo/hi.py"],
         ),
+        globs_to_regex_params(
+            ["*c/foo"], case_insensitive=False, partial=True,
+            matches=["abc/foo/hi.py"],
+            nomatches=["abc/xfoo/hi.py", "foo/hi.py", "def/abc/foo/hi.py"],
+        ),
+        globs_to_regex_params(
+            ["foo/x*"], case_insensitive=False, partial=True,
+            matches=["foo/x", "foo/xhi.py", "foo/x/hi.py"],
+            nomatches=[],
+        ),
+        globs_to_regex_params(
+            ["foo/x*"], case_insensitive=False, partial=False,
+            matches=["foo/x", "foo/xhi.py"],
+            nomatches=["foo/x/hi.py"],
+        ),
         globs_to_regex_params(
             ["**/foo"],
             matches=["foo", "hello/foo", "hi/there/foo"],
@@ -248,7 +264,7 @@ def globs_to_regex_params(
             matches=["a+b/foo", "a+b/foobar", "x{y}z/foobar"],
             nomatches=["aab/foo", "ab/foo", "xyz/foo"],
         ),
-    ]))
+    ])),
 )
 def test_globs_to_regex(
     patterns: Iterable[str],
@@ -348,6 +364,7 @@ class MatcherTest(CoverageTest):
             (self.make_file("sub/file1.py"), True),
             (self.make_file("sub/file2.c"), False),
             (self.make_file("sub2/file3.h"), True),
+            (self.make_file("sub2/sub/file3.h"), True),
             (self.make_file("sub3/file4.py"), True),
             (self.make_file("sub3/file5.c"), False),
         ]
@@ -448,7 +465,7 @@ class PathAliasesTest(CoverageTest):
 
     def test_multiple_patterns(self, rel_yn: bool) -> None:
         # also test the debugfn...
-        msgs: List[str] = []
+        msgs: list[str] = []
         aliases = PathAliases(debugfn=msgs.append, relative=rel_yn)
         aliases.add('/home/*/src', './mysrc')
         aliases.add('/lib/*/libsrc', './mylib')
