@@ -27,7 +27,7 @@ from coverage.files import abs_file, python_reported_file
 
 from tests import testenv
 from tests.coveragetest import CoverageTest, TESTS_DIR
-from tests.helpers import re_line, re_lines, re_lines_text, without_color
+from tests.helpers import re_line, re_lines, re_lines_text
 
 
 class ProcessTest(CoverageTest):
@@ -318,7 +318,6 @@ class ProcessTest(CoverageTest):
         assert out == out2
 
         # But also make sure that the output is what we expect.
-        out = without_color(out)
         path = python_reported_file('throw.py')
         msg = f'File "{re.escape(path)}", line 8, in f2'
         assert re.search(msg, out)
@@ -607,7 +606,7 @@ class ProcessTest(CoverageTest):
             """)
 
         # Some of our testing infrastructure can issue warnings.
-        # Turn it all off for the sub-process.
+        # Turn it all off for the subprocess.
         self.del_environ("COVERAGE_TESTING")
 
         out = self.run_command("python allok.py")
@@ -731,7 +730,7 @@ class EnvironmentTest(CoverageTest):
         self.add_test_modules_to_pythonpath()
         expected = self.run_command("python -m process_test.try_execfile")
         actual = self.run_command(
-            "coverage run --source process_test.try_execfile -m process_test.try_execfile"
+            "coverage run --source process_test.try_execfile -m process_test.try_execfile",
         )
         self.assert_tryexecfile_output(expected, actual)
 
@@ -751,7 +750,7 @@ class EnvironmentTest(CoverageTest):
         self.add_test_modules_to_pythonpath()
         expected = self.run_command("python -m process_test.try_execfile")
         actual = self.run_command(
-            "coverage run --source process_test -m process_test.try_execfile"
+            "coverage run --source process_test -m process_test.try_execfile",
         )
         self.assert_tryexecfile_output(expected, actual)
 
@@ -816,7 +815,7 @@ class EnvironmentTest(CoverageTest):
             SOMETHING = "hello-xyzzy"
             """)
         abc = os.path.abspath("a/b/c")
-        self.make_file("run_coverage.py", """\
+        self.make_file("run_coverage.py", f"""\
             import sys
             sys.path[0:0] = [
                 r'{abc}',
@@ -827,7 +826,7 @@ class EnvironmentTest(CoverageTest):
 
             if __name__ == '__main__':
                 sys.exit(coverage.cmdline.main())
-            """.format(abc=abc))
+            """)
         self.make_file("how_is_it.py", """\
             import pprint, sys
             pprint.pprint(sys.path)
@@ -844,7 +843,7 @@ class EnvironmentTest(CoverageTest):
     @pytest.mark.skipif(env.WINDOWS, reason="Windows can't make symlinks")
     @pytest.mark.skipif(
         platform.python_version().endswith("+"),
-        reason="setuptools barfs on dev versions: https://github.com/pypa/packaging/issues/678"
+        reason="setuptools barfs on dev versions: https://github.com/pypa/packaging/issues/678",
         # https://github.com/nedbat/coveragepy/issues/1556
     )
     def test_bug_862(self) -> None:
@@ -925,10 +924,13 @@ class ExcepthookTest(CoverageTest):
         # executed.
         data = coverage.CoverageData()
         data.read()
+        print(f"{line_counts(data) = }")
+        print(f"{data = }")
+        print("data.lines excepthook.py:", data.lines(os.path.abspath('excepthook.py')))
         assert line_counts(data)['excepthook.py'] == 7
 
     @pytest.mark.skipif(not env.CPYTHON,
-        reason="non-CPython handles excepthook exits differently, punt for now."
+        reason="non-CPython handles excepthook exits differently, punt for now.",
     )
     def test_excepthook_exit(self) -> None:
         self.make_file("excepthook_exit.py", """\
@@ -970,11 +972,8 @@ class ExcepthookTest(CoverageTest):
         py_st, py_out = self.run_command_status("python excepthook_throw.py")
         assert cov_st == py_st
         assert cov_st == 1
-        assert "in excepthook" in without_color(py_out)
-        # Don't know why: the Python output shows "Error in sys.excepthook" and
-        # "Original exception" in color.  The coverage output has the first in
-        # color and "Original" without color? Strip all the color.
-        assert without_color(cov_out) == without_color(py_out)
+        assert "in excepthook" in py_out
+        assert cov_out == py_out
 
 
 class AliasedCommandTest(CoverageTest):
@@ -1077,7 +1076,7 @@ class FailUnderTest(CoverageTest):
             "a = 1\n" +
             "b = 2\n" * 2000 +
             "if a > 3:\n" +
-            "    c = 4\n"
+            "    c = 4\n",
         )
         self.make_data_file(lines={abs_file("ninety_nine_plus.py"): range(1, 2002)})
         st, out = self.run_command_status("coverage report --fail-under=100")
@@ -1126,7 +1125,6 @@ class CoverageCoreTest(CoverageTest):
         core = re_line(r" core:", out).strip()
         assert core == "core: PyTracer"
 
-    @pytest.mark.skipif(not env.PYBEHAVIOR.pep669, reason="No sys.monitoring to request")
     def test_core_request_sysmon(self) -> None:
         self.del_environ("COVERAGE_TEST_CORES")
         self.set_environ("COVERAGE_CORE", "sysmon")
@@ -1134,7 +1132,13 @@ class CoverageCoreTest(CoverageTest):
         out = self.run_command("coverage run --debug=sys numbers.py")
         assert out.endswith("123 456\n")
         core = re_line(r" core:", out).strip()
-        assert core == "core: SysMonitor"
+        warns = re_lines(r"CoverageWarning: sys.monitoring isn't available", out)
+        if env.PYBEHAVIOR.pep669:
+            assert core == "core: SysMonitor"
+            assert not warns
+        else:
+            assert core in ("core: CTracer", "core: PyTracer")
+            assert warns
 
 
 class FailUnderNoFilesTest(CoverageTest):
@@ -1181,7 +1185,6 @@ class YankedDirectoryTest(CoverageTest):
     def test_removing_directory_with_error(self) -> None:
         self.make_file("bug806.py", self.BUG_806)
         out = self.run_command("coverage run bug806.py")
-        out = without_color(out)
         path = python_reported_file('bug806.py')
         # Python 3.11 adds an extra line to the traceback.
         # Check that the lines we expect are there.
@@ -1194,9 +1197,9 @@ class YankedDirectoryTest(CoverageTest):
         assert all(line in out for line in lines)
 
 
-@pytest.mark.skipif(env.METACOV, reason="Can't test sub-process pth file during metacoverage")
+@pytest.mark.skipif(env.METACOV, reason="Can't test subprocess pth file during metacoverage")
 class ProcessStartupTest(CoverageTest):
-    """Test that we can measure coverage in sub-processes."""
+    """Test that we can measure coverage in subprocesses."""
 
     def setUp(self) -> None:
         super().setUp()
